const std = @import("std");
const file_op = @import("file_op.zig");

pub fn main() !void {
    const filename = "todo-db.txt";
    var gpa = std.heap.GeneralPurposeAllocator(.{}){};
    defer _ = gpa.deinit();
    const allocator = gpa.allocator();

    var file_res = file_op.readTasksFromFile(allocator, filename) catch |err| {
        std.debug.print("Failed read or create file, exiting ...", .{});
        return err;
    };

    defer {
        for (file_res.tasks.items) |task| {
            allocator.free(task);
        }
        file_res.tasks.deinit();
        file_res.file.close();
    }

    std.debug.print("Reading from file:\n", .{});
    for (file_res.tasks.items) |i| {
        std.debug.print("{s}\n", .{i});
    }

    try userInteraction();

    file_op.writeTasksToFile(file_res) catch |err| {
        std.debug.print("Error while writing data to file:\n{}", .{err});
    };
}

fn userInteraction() !void {
    const stdin = std.io.getStdIn().reader();
    const stdout = std.io.getStdOut().writer();
    // var buf: [100]u8 = undefined;

    while (true) {
        try stdout.print("Please enter your choice add/remove/edit/quit: ", .{});
        const bare_line = try stdin.readUntilDelimiterAlloc(std.heap.page_allocator, '\n', 8192);
        defer std.heap.page_allocator.free(bare_line);
        // windows legacy
        const line = std.mem.trim(u8, bare_line, "\r");
        std.debug.print("You entered: {s}\n", .{line});

        const Case = enum { add, edit, delete, quit };
        const case = std.meta.stringToEnum(Case, line) orelse return;

        switch (case) {
            .add => {},
            .edit => {},
            .delete => {},
            .quit => break,
        }

        //break;
    }
}
